Flibdivsufsort


SuffixArray

Namespace: global
Parent Module: Flibdivsufsort

Suffix Array Wrapper Type, The only Input Parameter is a string. May throw SuffixArrayCreationFailureException.

Constructors

ConstructorDescription
new(input)
Signature: (input:byte []) -> SuffixArray

CompiledName: .ctor

Instance members

Instance memberDescription
IsCorrect()
Signature: unit -> bool

Checks if the initialized Suffix Array was created correctly.

Search(query)
Signature: (query:byte []) -> int64 []

Searches the Suffix Array for the given pattern. Returns indicies into the original input string where the pattern was found.

Fork me on GitHub