Flibdivsufsort
Namespace: global
Nested types and modules
| Type | Description |
| SuffixArray | Suffix Array Wrapper Type, The only Input Parameter is a string. May throw SuffixArrayCreationFailureException. |
| SuffixArrayCreationFailureException | Occurs when an error happens when a suffix array is initialized |